%define pypi_name	ephem

Summary:	Scientific-grade astronomical computations for python
Name:		python-ephem
Version:	4.1.3
Release:	%mkrel 1
License:	LGPLv3
Group:		Development/Python
URL:		https://rhodesmill.org/pyephem/
Source:		%{pypi_source}
Patch0:		ephem-3.7.7.1-fix-linking.patch

%description
PyEphem provides scientific-grade astronomical computations for the
Python programming language. Given a date and location on the Earth’s
surface, it can compute the positions of the Sun and Moon, of the
planets and their moons, and of any asteroids, comets, or earth
satellites whose orbital elements the user can provide. Additional
functions are provided to compute the angular separation between two
objects in the sky, to determine the constellation in which an object
lies, and to find the times at which an object rises, transits, and
sets on a particular day. The numerical routines that lie behind
PyEphem are those from the wonderful XEphem astronomy application,
whose author, Elwood Downey, generously gave permission for us to use
them as the basis for PyEphem.



%package -n python3-ephem
Summary:        Python3 implementation of Ephem
Group:          Development/Python
BuildRequires: pyproject-rpm-macros
BuildRequires:  pkgconfig(python3)
Provides:       ephem = %{version}-%{release}
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-ephem
PyEphem provides scientific-grade astronomical computations for the
Python programming language. Given a date and location on the Earth’s
surface, it can compute the positions of the Sun and Moon, of the
planets and their moons, and of any asteroids, comets, or earth
satellites whose orbital elements the user can provide. Additional
functions are provided to compute the angular separation between two
objects in the sky, to determine the constellation in which an object
lies, and to find the times at which an object rises, transits, and
sets on a particular day. The numerical routines that lie behind
PyEphem are those from the wonderful XEphem astronomy application,
whose author, Elwood Downey, generously gave permission for us to use
them as the basis for PyEphem.


%prep
%autosetup -n %{pypi_name}-%{version} -p1


%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files ephem

%files -n python3-ephem -f %{pyproject_files}
%{python3_sitearch}/ephem
%{python3_sitearch}/%{pypi_name}-*


%changelog
* Wed Sep 07 2022 neoclust <neoclust> 4.1.3-1.mga9
+ Revision: 1884702
- New version 	4.1.3

* Sat Mar 19 2022 umeabot <umeabot> 4.1.1-2.mga9
+ Revision: 1799315
- Mageia 9 Mass Rebuild

* Sat Feb 26 2022 mrambo3501 <mrambo3501> 4.1.1-1.mga9
+ Revision: 1784999
- version 4.1.1
- rediff Patch0
- rebuild for python-3.10

* Tue Apr 20 2021 daviddavid <daviddavid> 3.7.7.1-2.mga9
+ Revision: 1717374
- rebuild for python 3.9

* Thu Oct 01 2020 guillomovitch <guillomovitch> 3.7.7.1-1.mga8
+ Revision: 1631494
- new version 3.7.7.1

* Sun Feb 16 2020 umeabot <umeabot> 3.7.6.0-6.mga8
+ Revision: 1535557
- Mageia 8 Mass Rebuild
+ tv <tv>
- revert underlinking "fix"
- "fix" underlinking

* Sat Oct 12 2019 daviddavid <daviddavid> 3.7.6.0-5.mga8
+ Revision: 1452195
- add patch to fix linking issue
+ tv <tv>
- rebuild for python-3.8
- drop python2 subpkg

* Tue Jan 08 2019 shlomif <shlomif> 3.7.6.0-4.mga7
+ Revision: 1352657
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 3.7.6.0-3.mga7
+ Revision: 1300473
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 3.7.6.0-2.mga7
+ Revision: 1135414
- Rebuild for python 3.6

* Fri Dec 16 2016 eatdirt <eatdirt> 3.7.6.0-1.mga6
+ Revision: 1075641
- Upgrade to version 3.7.6.0 + add python3 support

* Tue Feb 02 2016 umeabot <umeabot> 3.7.5.1-8.mga6
+ Revision: 932764
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.7.5.1-7.mga5
+ Revision: 745020
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.7.5.1-6.mga5
+ Revision: 728403
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.7.5.1-5.mga5
+ Revision: 688019
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 3.7.5.1-3.mga4
+ Revision: 543288
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.7.5.1-2.mga4
+ Revision: 498545
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Aug 03 2013 joequant <joequant> 3.7.5.1-1.mga4
+ Revision: 462994
- update to 3.7.5.1

* Sun Jan 13 2013 umeabot <umeabot> 3.7.4.1-2.mga3
+ Revision: 378802
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat May 14 2011 mikala <mikala> 3.7.4.1-1.mga1
+ Revision: 98749
- Update tarball to 3.7.4.1 (thks to pterjan for the patch)
- imported package python-ephem
+ pterjan <pterjan>
- link with libm


* Sun Nov 15 2009 John Balcaen <mikala@mandriva.org> 3.7.3.4-1mdv2010.1
+ Revision: 466170
- import python-ephem

